@@ -6,7 +6,7 @@ use Carp ();
 use Module::CPANfile::Environment;
 use Module::CPANfile::Requirement;
 
-our $VERSION = '1.0904';
+our $VERSION = '1.0905';
 
 sub new {
     my($class, $file) = @_;
@@ -39,6 +39,7 @@ sub parse {
     my $env = Module::CPANfile::Environment->new($file);
     $env->parse($code) or die $@;
 
+    $self->{_mirrors} = $env->mirrors;
     $self->{_prereqs} = $env->prereqs;
 }
 
@@ -51,6 +52,11 @@ sub from_prereqs {
     $self;
 }
 
+sub mirrors {
+    my $self = shift;
+    $self->{_mirrors} || [];
+}
+
 sub features {
     my $self = shift;
     map $self->feature($_), $self->{_prereqs}->identifiers;
@@ -129,9 +135,11 @@ sub _dump {
 sub to_string {
     my($self, $include_empty) = @_;
 
+    my $mirrors = $self->mirrors;
     my $prereqs = $self->prereq_specs;
 
     my $code = '';
+    $code .= $self->_dump_mirrors($mirrors);
     $code .= $self->_dump_prereqs($prereqs, $include_empty);
 
     for my $feature ($self->features) {
@@ -144,6 +152,19 @@ sub to_string {
     $code;
 }
 
+sub _dump_mirrors {
+    my($self, $mirrors) = @_;
+
+    my $code = "";
+
+    for my $url (@$mirrors) {
+        $code .= "mirror '$url';\n";
+    }
+
+    $code =~ s/\n+$/\n/s;
+    $code;
+}
+
 sub _dump_prereqs {
     my($self, $prereqs, $include_empty, $base_indent) = @_;
 
